@@ -44,7 +44,7 @@
 #endif
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <gdkconfig.h>
 #ifdef GDK_WINDOWING_X11
@@ -96,17 +96,12 @@ static void libgnomeui_class_init	(GnomeProgramClass *klass,
 					 const GnomeModuleInfo *mod_info);
 static void libgnomeui_instance_init	(GnomeProgram *program,
 					 GnomeModuleInfo *mod_info);
-static void libgnomeui_pre_args_parse	(GnomeProgram *app,
-					 GnomeModuleInfo *mod_info);
 static void libgnomeui_post_args_parse	(GnomeProgram *app,
 					 GnomeModuleInfo *mod_info);
 static void libgnomeui_rc_parse		(GnomeProgram *program);
-#ifndef G_OS_WIN32
-static void libgnomeui_segv_setup	(GnomeProgram *program);
-#endif
 
 /* Prototype for a private gnome_stock function */
-void _gnome_stock_icons_init (void);
+G_GNUC_INTERNAL void _gnome_stock_icons_init (void);
 
 /* Whether to make noises when the user clicks a button, etc.  We cache it
  * in a boolean rather than querying GConf every time.
@@ -116,28 +111,8 @@ static gboolean use_event_sounds;
 /* GConf client for monitoring the event sounds option */
 static GConfClient *gconf_client = NULL;
 
-
 enum { ARG_DISABLE_CRASH_DIALOG=1, ARG_DISPLAY };
 
-static struct poptOption libgnomeui_options[] = {
-        {NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
-	{NULL, '\0', POPT_ARG_CALLBACK|POPT_CBFLAG_PRE|POPT_CBFLAG_POST,
-	 &libgnomeui_arg_callback, 0, NULL, NULL},
-	{"disable-crash-dialog", '\0', POPT_ARG_NONE, NULL, ARG_DISABLE_CRASH_DIALOG,
-        N_("Disable Crash Dialog"), NULL},
-        {"display", '\0', POPT_ARG_STRING|POPT_ARGFLAG_DOC_HIDDEN, NULL, ARG_DISPLAY,
-         N_("X display to use"), N_("DISPLAY")},
-	{NULL, '\0', 0, NULL, 0, NULL, NULL}
-};
-
-static GOptionEntry libgnomeui_goptions[] = {
-	{ "disable-crash-dialog", '\0', G_OPTION_FLAG_NO_ARG,
-	  G_OPTION_ARG_CALLBACK, libgnomeui_goption_disable_crash_dialog,
-	  N_("Disable Crash Dialog"), NULL },
-	/* --display is already handled by gtk+ */
-	{ NULL }
-};
-
 G_GNUC_INTERNAL void _gnome_ui_gettext_init (gboolean);
 
 void G_GNUC_INTERNAL
@@ -165,6 +140,13 @@ _gnome_ui_gettext_init (gboolean bind_codeset)
 static GOptionGroup *
 libgnomeui_get_goption_group (void)
 {
+	const GOptionEntry libgnomeui_goptions[] = {
+		{ "disable-crash-dialog", '\0', G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN,
+		  G_OPTION_ARG_CALLBACK, libgnomeui_goption_disable_crash_dialog,
+		  N_("Disable Crash Dialog"), NULL },
+		  /* --display is already handled by gtk+ */
+		{ NULL }
+	};
 	GOptionGroup *option_group;
 
 	_gnome_ui_gettext_init (TRUE);
@@ -182,10 +164,21 @@ libgnomeui_get_goption_group (void)
 const GnomeModuleInfo *
 libgnomeui_module_info_get (void)
 {
+	static struct poptOption libgnomeui_options[] = {
+		{ NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL },
+		{ NULL, '\0', POPT_ARG_CALLBACK|POPT_CBFLAG_PRE|POPT_CBFLAG_POST,
+		  &libgnomeui_arg_callback, 0, NULL, NULL },
+		{ "disable-crash-dialog", '\0', POPT_ARG_NONE, NULL, ARG_DISABLE_CRASH_DIALOG,
+		  N_("Disable Crash Dialog"), NULL },
+		{ "display", '\0', POPT_ARG_STRING|POPT_ARGFLAG_DOC_HIDDEN, NULL, ARG_DISPLAY,
+		  N_("X display to use"), N_("DISPLAY") },
+		{ NULL, '\0', 0, NULL, 0, NULL, NULL }
+	};
+
 	static GnomeModuleInfo module_info = {
 		"libgnomeui", VERSION, N_("GNOME GUI Library"),
 		NULL, libgnomeui_instance_init,
-		libgnomeui_pre_args_parse, libgnomeui_post_args_parse,
+		NULL, libgnomeui_post_args_parse,
 		libgnomeui_options,
 		libgnomeui_init_pass, libgnomeui_class_init,
 		NULL, NULL
@@ -238,8 +231,7 @@ show_url (GtkWidget *parent,
 	GdkScreen *screen;
 	GError *error = NULL;
 
-	if (parent != NULL)
-		screen = gtk_widget_get_screen (parent);
+	screen = gtk_widget_get_screen (parent);
 
 	if (!gnome_url_show_on_screen (url, screen, &error))
 	{
@@ -397,21 +389,6 @@ libgnomeui_instance_init (GnomeProgram *program, GnomeModuleInfo *mod_info)
 			     priv, (GDestroyNotify) libgnomeui_private_free);
 }
 
-static void
-libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
-{
-        const char *envar;
-
-        /* This is one of two places where the crash dialog can be disabled */
-        /* The other is the command line option --disable-crash-dialog, so */
-        /* we wait until post_args_parse before calling libgnomeui_segv_setup */
-        envar = g_getenv("GNOME_DISABLE_CRASH_DIALOG");
-        if (envar && atoi (envar))
-		g_object_set (G_OBJECT(app),
-			      LIBGNOMEUI_PARAM_CRASH_DIALOG, FALSE,
-			      NULL);
-}
-
 static gboolean
 relay_gnome_signal (GSignalInvocationHint *hint,
               	     guint n_param_values,
@@ -653,9 +630,6 @@ libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
 
         gnome_type_init();
         libgnomeui_rc_parse (program);
-#ifndef G_OS_WIN32
-        libgnomeui_segv_setup (program);
-#endif
         priv = g_object_get_qdata(G_OBJECT(program), quark_gnome_program_private_libgnomeui);
 
         priv->constructed = TRUE;
@@ -787,124 +761,6 @@ libgnomeui_rc_parse (GnomeProgram *program)
 	}
 }
 
-#ifndef G_OS_WIN32
-
-/* crash handler */
-static void libgnomeui_segv_handle(int signum);
-
-static void
-libgnomeui_segv_setup (GnomeProgram *program)
-{
-        static struct sigaction *setptr;
-        struct sigaction sa;
-        gboolean do_crash_dialog = TRUE;
-        GValue value = { 0, };
-
-        g_value_init (&value, G_TYPE_BOOLEAN);
-        g_object_get_property (G_OBJECT (program),
-                               LIBGNOMEUI_PARAM_CRASH_DIALOG, &value);
-        do_crash_dialog = g_value_get_boolean (&value);
-        g_value_unset (&value);
-
-        if(do_crash_dialog) {
-                memset(&sa, 0, sizeof(sa));
-                setptr = &sa;
-
-                sa.sa_handler = (gpointer)libgnomeui_segv_handle;
-
-                sigaction(SIGSEGV, setptr, NULL);
-                sigaction(SIGABRT, setptr, NULL);
-                sigaction(SIGTRAP, setptr, NULL);
-                sigaction(SIGFPE, setptr, NULL);
-                sigaction(SIGBUS, setptr, NULL);
-        }
-
-}
-
-static void libgnomeui_segv_handle(int signum)
-{
-	static int in_segv = 0;
-        struct sigaction sa;
-	pid_t pid;
-	
-	sa.sa_handler = NULL;
-	in_segv++;
-
-        if (in_segv > 2) {
-                /* The fprintf() was segfaulting, we are just totally hosed */
-                _exit(1);
-        } else if (in_segv > 1) {
-                /* dialog display isn't working out */
-                fprintf(stderr, _("Multiple segmentation faults occurred; can't display error dialog\n"));
-                _exit(1);
-        }
-
-        /* Make sure we release grabs */
-        gdk_pointer_ungrab(GDK_CURRENT_TIME);
-        gdk_keyboard_ungrab(GDK_CURRENT_TIME);
-        XUngrabServer (GDK_DISPLAY ());
-
-        gdk_flush();
-        
-	pid = fork();
-
-	if (pid < 0) {
-		/* Eeeek! Can't show dialog */
-                fprintf (stderr, _("Segmentation fault!\n"
-				   "Cannot display crash dialog\n"));
-
-                /* Don't use app attributes here - a lot of things are probably hosed */
-		if (g_getenv ("GNOME_DUMP_CORE")) {
-                        /* Reset SIGABRT so we don't get called again. */
-                        sa.sa_handler = SIG_DFL;
-                        sigaction (SIGABRT, &sa, NULL);
-	                abort ();
-                }
-
-		_exit(1);
-	} else if (pid > 0) {
-                /* Wait for user to see the dialog, then exit. */
-                /* Why wait at all? Because we want to allow people to attach to the
-		   process */
-		int estatus;
-		pid_t eret;
-
-		eret = waitpid(pid, &estatus, 0);
-
-                /* Don't use app attributes here - a lot of things are probably hosed */
-		if(g_getenv("GNOME_DUMP_CORE")) {
-                        /* Reset SIGABRT so we don't get called again. */
-                        sa.sa_handler = SIG_DFL;
-                        sigaction (SIGABRT, &sa, NULL);
-	                abort ();
-                }
-
-		_exit(1);
-	} else /* pid == 0 */ {
-                GnomeProgram *program;
-		char buf[32];
-
-		g_snprintf(buf, sizeof(buf), "%d", signum);
-
-                program = gnome_program_get();
-
-		/* Child process */
-		execl (LIBGNOMEUI_SERVERDIR "/gnome_segv2", LIBGNOMEUI_SERVERDIR "/gnome_segv",
-		       g_get_prgname (), buf,
-		       gnome_program_get_app_version (program), NULL);
-
-                execlp ("gnome_segv2", "gnome_segv2",
-			g_get_prgname (), buf,
-			gnome_program_get_app_version (program), NULL);
-
-                _exit(99);
-	}
-
-	in_segv--;
-}
-
-#endif
-
 /* #warning "Solve the sound events situation" */
 
 /* backwards compat */
@@ -947,13 +803,9 @@ gnome_init_with_popt_table (const char *app_id,
 				      NULL);
 
         if(return_ctx) {
-                GValue value = { 0, };
-
-                g_value_init (&value, G_TYPE_POINTER);
-                g_object_get_property (G_OBJECT (program),
-                                       GNOME_PARAM_POPT_CONTEXT, &value);
-                *return_ctx = g_value_peek_pointer (&value);
-                g_value_unset (&value);
+                poptContext context;
+                g_object_get (program, GNOME_PARAM_POPT_CONTEXT, &context, NULL);
+                *return_ctx = context;
         }
 
         return 0;
